@@ -1,11 +1,12 @@
-package Catalyst::Authentication::Credential::RPX;
-our $VERSION = '0.0920400';
-
-
-# ABSTRACT: Use JanRains RPX service for Credentials
-
 use strict;
 use warnings;
+
+package Catalyst::Authentication::Credential::RPX;
+our $VERSION = '0.10003903';
+
+
+# ABSTRACT: Use JanRain's RPX service for Credentials
+
 use Moose;
 use MooseX::Types::Moose qw( :all );
 use MooseX::Has::Sugar;
@@ -14,9 +15,6 @@ use Net::API::RPX;
 
 
 
-has '_config'     => ( isa => HashRef, rw, required, );
-has '_app'        => ( isa => Object,  rw, required, );
-has '_realm'      => ( isa => Object,  rw, required, );
 has 'api_key'     => ( isa => Str,     ro, required, );
 has 'base_url'    => ( isa => Str,     ro, predicate => 'has_base_url', );
 has 'ua'          => ( isa => Str,     ro, predicate => 'has_ua', );
@@ -30,6 +28,11 @@ has 'last_auth_info' => (
   clearer   => 'clear_last_auth_info',
 );
 
+
+
+has '_config'     => ( isa => HashRef, rw, required, );
+has '_app'        => ( isa => Object,  rw, required, );
+has '_realm'      => ( isa => Object,  rw, required, );
 has '_api_driver' => (
   lazy_build, ro,
   isa      => Object,
@@ -37,22 +40,25 @@ has '_api_driver' => (
   handles  => [qw( auth_info map unmap mappings )],
 );
 
+
 sub BUILDARGS {
-  my $class = shift;
-  if ( @_ == 3 ) {
+  my ( $class, @arg_list ) = @_;
+  ## no critic (ProhibitMagicNumbers)
+  if ( @arg_list == 3 ) {
     my %args = (
-      _config => $_[0],
-      _app    => $_[1],
-      _realm  => $_[2],
+      _config => $arg_list[0],
+      _app    => $arg_list[1],
+      _realm  => $arg_list[2],
     );
     for ( keys %{ $args{'_config'} } ) {
       $args{$_} = $args{'_config'}->{$_};
     }
     return $class->SUPER::BUILDARGS(%args);
   }
-  return $class->SUPER::BUILDARGS(@_);
+  return $class->SUPER::BUILDARGS(@arg_list);
 }
 
+
 sub _build__api_driver {
   my $self = shift;
   my $conf = { api_key => $self->api_key };
@@ -65,13 +71,14 @@ sub _build__api_driver {
   return Net::API::RPX->new($conf);
 }
 
+
 sub authenticate {
   my ( $self, $c, $realm, $authinfo ) = @_;
   my $token_field = $self->token_field;
   my $token;
 
   unless ( exists $c->req->params->{$token_field} ) {
-    return undef;
+    return;
   }
 
   $token = $c->req->params->{$token_field};
@@ -79,20 +86,23 @@ sub authenticate {
   my $result = $self->authenticate_rpx( { token => $token } );
 
   if ( exists $result->{'err'} ) {
-    return undef;
+    return;
   }
 
   return $result;
 
 }
 
+
 sub authenticate_rpx {
-  my $self = shift;
+  my ( $self, @args ) = @_;
   $self->clear_last_auth_info if $self->has_last_auth_info;
-  my $result = $self->_api_driver->auth_info(@_);
+  my $result = $self->_api_driver->auth_info(@args);
   $self->last_auth_info($result);
   return $result;
 }
+no Moose;
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -103,11 +113,11 @@ __END__
 
 =head1 NAME
 
-Catalyst::Authentication::Credential::RPX - Use JanRains RPX service for Credentials
+Catalyst::Authentication::Credential::RPX - Use JanRain's RPX service for Credentials
 
 =head1 VERSION
 
-version 0.0920400
+version 0.10003903
 
 =head1 SYNOPSIS
 
@@ -141,31 +151,99 @@ version 0.0920400
       }
     });
 
+
+
 =head1 ATTRIBUTES
 
-=over 4
-
-=item * C<api_key>  | C< ro required Str >
+=head2 api_key
 
 The API Key for connecting to the RPX server.
 
-=item * C<base_url>  | C< ro Str predicate=has_base_url >
+=head4 type: ro required Str
+
+=head2 base_url
 
 The URL The RPX server interconnects with.
 
-=item * C<ua> | C< ro Str predicate=has_ua >
+=head4 type: ro Str predicate=has_base_url
+
+=head2 ua
 
 The User-Agent String.
 
-=item * C<token_field> | C< ro Str default='token' >
+=head4 type: ro Str predicate=has_ua
 
-The token to look for in request params
+=head2 token_field
 
-=item * C<last_auth_info> | C< rw HashRef predicate=has_last_auth_info  clearer=clear_last_auth_info >
+The token to look for in request parameters
+
+=head4 type: ro Str default = 'token
+
+=head2 last_auth_info
 
 The results of the last call to C<< ->auth_info >>
 
-=back
+=head4 type: rw HashRef predicate = has_last_auth_info clearer = clear_last_auth_info
+
+
+
+=head1 PRIVATE ATTRIBUTES
+
+=head2 _config
+
+=head4 type: rw required HashRef
+
+=head2 _app
+
+=head4 type: rw required Object
+
+=head2 _realm
+
+=head4 type: rw required Object
+
+=head2 _api_driver
+
+=head4 type: ro lazy_build Object
+
+=head4 handles: auth_info map unmap mappings
+
+
+
+=head1 METHODS
+
+=head2 CONSTRUCTOR
+
+=head3 new
+
+This method is called by the Authentication API.
+
+=head4 signature: ->new( $config , $app , $realm );
+
+
+
+=head2 BUILDERS ( Private )
+
+=head3 _build__api_driver
+
+Creates an instance of L<Net::API::RPX> for us to communicate with.
+
+=head4 signature: ->_build__api_driver
+
+
+
+=head2 AUTHENTICATION
+
+=head3 authenticate
+
+=head4 signature: ->authenticate( $context, $realm, $authinfo )
+
+
+
+=head3 authenticate_rpx
+
+=head4 signature: ->authenticate_rpx( @args )
+
+
 
 =head1 AUTHOR
 
@@ -179,6 +257,6 @@ This is free software, licensed under:
 
   The (three-clause) BSD License
 
-=cut
+=cut 
 
 
